Registration
Description: Biometric and RFID time recorders. Develops time and attendance and access control software.
Keywords: Innux , timeclocks, time , recorders, attendance , biometric , fingerprint , clock , access, control , software, data, collection

- Skip to content
- Skip to main navigation
- Skip to columns

# Innux Technologies Lda

- Home
- Company
  - Sectors of Activity
  - Markets
  - Success Cases
  - Recruitment
- Software
  - Attendance Management
    - InnuxTime
    - InnuxTime Advance
    - WebTime
    - WebCalendar
    - XWeb
  - Access Control
    - InnuxAccess
    - InnuxAccess Online
  - Guard Tour Control
  - Production Control
    - InnuxProduction
    - Innux WebObra
  - Ticketing Management
  - Healthclub Management
  - Service Control
  - Document Management
  - Teacher Management
  - Customer Loyalty
  - Race Timming Control
- Hardware
  - Attendance Control
    - NuxFace
    - NuxPro II
    - NuxBio III
    - NuxBio IV
    - NuxPalm
    - NuxIn
    - NuxBio II
    - NuxIn II
    - NuxFinger
    - NuxPro
    - NuxMag
    - NuxMobile
  - Access Control
    - NuxIn
    - NuxIn II
    - NuxBio AC
    - NuxFace
    - NuxPalm
    - NuxKey
  - Car Park
    - Entry Station
    - Exit Station
    - Payment Kiosk
  - Guard Tour Control
    - NuxTour
    - NuxMobile
    - NuxMobile GSM
  - Production Control
    - NuxPro Online
    - NuxBio II
  - Automation and Control
    - NuxIO Board
    - NuxIO II Board
  - Card Printers
    - Zebra P430i
    - Magicard Enduro
    - Magicard Pronto
    - Tapes and Consumables
  - Turnstiles
    - TornLine
    - TornRobust
    - TornGlass
    - TornMax
    - TornFull
    - TornVirtual
  - Readers
    - NuxReader I
    - NuxReader II
    - NuxID
  - RFID Tags
    - RFID Cards
    - RFID Disks
    - RFID Keyfob
- Press
  - Announcements
  - Press Folder
  - Image Bank
- Contacts

Home » Register » New
Registration

Company name: | *
Name: | *
Department: | *
Phone: | *
Country: | *
Market sector: | *
Publication name: |
Username: | *
E-mail: | *
Password: | *
Verify Password: | *
Fields marked with an asterisk (*) are required.

### Menu

Home
Company
Software
Hardware
Press
Contacts

### Resources

Licenses
Downloads

### Contacts

Headquarters
Rua José Moura Coutinho,
Nº 608, 1º Andar
4745-330 Trofa
Portugal

+351 229 812 220
+351 229 812 222